==> haskell-hls-refactor-plugin-2.1.0.0-96-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-refactor-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-refactor-plugin
version:              2.1.0.0
visibility:           public
id:                   hls-refactor-plugin-2.1.0.0-6Z743muDD7MCtHloTxAduN
key:                  hls-refactor-plugin-2.1.0.0-6Z743muDD7MCtHloTxAduN
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           zubin.duggal@gmail.com
author:               The Haskell IDE Team
synopsis:             Exactprint refactorings for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  c45d74d6477b18045f4d3e01fc4596f5
exposed:              True
exposed-modules:
    Development.IDE.GHC.Compat.ExactPrint Development.IDE.GHC.Dump
    Development.IDE.GHC.ExactPrint Development.IDE.Plugin.CodeAction
    Development.IDE.Plugin.CodeAction.Util

hidden-modules:
    Development.IDE.Plugin.CodeAction.Args
    Development.IDE.Plugin.CodeAction.ExactPrint
    Development.IDE.Plugin.CodeAction.PositionIndexed
    Development.IDE.Plugin.Plugins.AddArgument
    Development.IDE.Plugin.Plugins.Diagnostic
    Development.IDE.Plugin.Plugins.FillHole
    Development.IDE.Plugin.Plugins.FillTypeWildcard
    Development.IDE.Plugin.Plugins.ImportUtils

import-dirs:          /usr/lib/ghc-9.6.6/site-local/hls-refactor-plugin-2.1.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hls-refactor-plugin-2.1.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hls-refactor-plugin-2.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-refactor-plugin
hs-libraries:         HShls-refactor-plugin-2.1.0.0-6Z743muDD7MCtHloTxAduN
depends:
    aeson-2.1.2.1-KAplhvfLEdp6k37mi9zTZA base-4.18.2.1
    bytestring-0.11.5.3 containers-0.6.7
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz deepseq-1.4.8.1
    dlist-1.0-B7D1vsARFiIHVaGk5CGbYO
    extra-1.7.16-8xfhX7g6qo3J4L1mTio5RX ghc-9.6.6 ghc-boot-9.6.6
    ghc-exactprint-1.7.1.0-9QJxe04AnCrAMTyjz1R5Eo
    ghcide-2.1.0.0-BerAul44zlBJVeBRUCvfbQ
    hls-graph-2.1.0.0-AnnGhkK1XyC58SRIh9W1Uv
    hls-plugin-api-2.1.0.0-4QMuRDYsW7V7FsZGARYFcA
    lens-5.3.3-ATynRreA1Nv2YBaKYxJYCc
    lsp-2.1.0.0-2ZaSj8xN9IEEbeKp3IMq36 mtl-2.3.1
    parser-combinators-1.3.0-20UTEUZ5CKDJdRu747ID48
    regex-applicative-0.3.4-6qQE9eOQZp5HKxWcp1ExAV
    regex-tdfa-1.3.2.5-HbcBjlVCDu1Hxg2xP0HSjv
    retrie-1.2.3-D1jPpbL02vmFR2jtsuSZui syb-0.7.3-MvqtDDcT2PHyhdKWhEKAp
    text-2.0.2 text-rope-0.3-K0ymPECMey344aObQAXYZP time-1.12.2
    transformers-0.6.1.0
    unordered-containers-0.2.20.1-CjV5euINhym8dGoasHPURS

haddock-interfaces:
    /usr/share/doc/haskell-hls-refactor-plugin/html/hls-refactor-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-refactor-plugin/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-refactor-plugin-2.1.0.0-98-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-refactor-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-refactor-plugin
version:              2.1.0.0
visibility:           public
id:                   hls-refactor-plugin-2.1.0.0-7to4sE0rCUi3SwL6caooL
key:                  hls-refactor-plugin-2.1.0.0-7to4sE0rCUi3SwL6caooL
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           zubin.duggal@gmail.com
author:               The Haskell IDE Team
synopsis:             Exactprint refactorings for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  41ce2ddda147db868ca380c5a429ede5
exposed:              True
exposed-modules:
    Development.IDE.GHC.Compat.ExactPrint Development.IDE.GHC.Dump
    Development.IDE.GHC.ExactPrint Development.IDE.Plugin.CodeAction
    Development.IDE.Plugin.CodeAction.Util

hidden-modules:
    Development.IDE.Plugin.CodeAction.Args
    Development.IDE.Plugin.CodeAction.ExactPrint
    Development.IDE.Plugin.CodeAction.PositionIndexed
    Development.IDE.Plugin.Plugins.AddArgument
    Development.IDE.Plugin.Plugins.Diagnostic
    Development.IDE.Plugin.Plugins.FillHole
    Development.IDE.Plugin.Plugins.FillTypeWildcard
    Development.IDE.Plugin.Plugins.ImportUtils

import-dirs:          /usr/lib/ghc-9.6.6/site-local/hls-refactor-plugin-2.1.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hls-refactor-plugin-2.1.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hls-refactor-plugin-2.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-refactor-plugin
hs-libraries:         HShls-refactor-plugin-2.1.0.0-7to4sE0rCUi3SwL6caooL
depends:
    aeson-2.1.2.1-JZeWX2s1eQL7Ta3HF3w6fW base-4.18.2.1
    bytestring-0.11.5.3 containers-0.6.7
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz deepseq-1.4.8.1
    dlist-1.0-B7D1vsARFiIHVaGk5CGbYO
    extra-1.7.16-LWra3MmVE7hIjr4mBFp6lZ ghc-9.6.6 ghc-boot-9.6.6
    ghc-exactprint-1.7.1.0-28VXJvpmOg9B2iU38G4Ie3
    ghcide-2.1.0.0-2g0zVyr13R05tQdzJ22MdQ
    hls-graph-2.1.0.0-87A0WuFLvjPFTcLdsimLM9
    hls-plugin-api-2.1.0.0-5cMP0MmQyvFBbS6jlRL1Kv
    lens-5.3.3-6yFfjYmjPBKuNNVCwyEN9 lsp-2.1.0.0-CRnztk6cHmsG62CXZIldVr
    mtl-2.3.1 parser-combinators-1.3.0-20UTEUZ5CKDJdRu747ID48
    regex-applicative-0.3.4-Cmv5Ug6GmSsKw5VrN0RAve
    regex-tdfa-1.3.2.5-qZoXOptISAJcpXFSPLOTl
    retrie-1.2.3-BfAKY2oU9Oe1B4ZPDGNeWC
    syb-0.7.3-7GPFF4ffw0kLXaCjDkD2wt text-2.0.2
    text-rope-0.3-BehqrDch9ZO9R3I8Glr3Gp time-1.12.2
    transformers-0.6.1.0
    unordered-containers-0.2.20.1-8SON4238u8N3rDHPceHjHx

haddock-interfaces:
    /usr/share/doc/haskell-hls-refactor-plugin/html/hls-refactor-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-refactor-plugin/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
